==> certmanager-model-v1alpha2-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VaultAppRoleBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VaultAppRoleBuilder extends VaultAppRoleFluentImpl<VaultAppRoleBuilder> implements VisitableBuilder<VaultAppRole,VaultAppRoleBuilder>{
  public VaultAppRoleBuilder() {
    this(false);
  }
  public VaultAppRoleBuilder(Boolean validationEnabled) {
    this(new VaultAppRole(), validationEnabled);
  }
  public VaultAppRoleBuilder(VaultAppRoleFluent<?> fluent) {
    this(fluent, false);
  }
  public VaultAppRoleBuilder(VaultAppRoleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VaultAppRole(), validationEnabled);
  }
  public VaultAppRoleBuilder(VaultAppRoleFluent<?> fluent,VaultAppRole instance) {
    this(fluent, instance, false);
  }
  public VaultAppRoleBuilder(VaultAppRoleFluent<?> fluent,VaultAppRole instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withPath(instance.getPath());
      fluent.withRoleId(instance.getRoleId());
      fluent.withSecretRef(instance.getSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VaultAppRoleBuilder(VaultAppRole instance) {
    this(instance,false);
  }
  public VaultAppRoleBuilder(VaultAppRole instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withPath(instance.getPath());
      this.withRoleId(instance.getRoleId());
      this.withSecretRef(instance.getSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  VaultAppRoleFluent<?> fluent;
  Boolean validationEnabled;
  public VaultAppRole build() {
    VaultAppRole buildable = new VaultAppRole(fluent.getPath(),fluent.getRoleId(),fluent.getSecretRef());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VaultAppRoleBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VaultAppRoleBuilder extends VaultAppRoleFluent<VaultAppRoleBuilder> implements VisitableBuilder<VaultAppRole,VaultAppRoleBuilder>{
  public VaultAppRoleBuilder() {
    this(false);
  }
  public VaultAppRoleBuilder(Boolean validationEnabled) {
    this(new VaultAppRole(), validationEnabled);
  }
  public VaultAppRoleBuilder(VaultAppRoleFluent<?> fluent) {
    this(fluent, false);
  }
  public VaultAppRoleBuilder(VaultAppRoleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VaultAppRole(), validationEnabled);
  }
  public VaultAppRoleBuilder(VaultAppRoleFluent<?> fluent,VaultAppRole instance) {
    this(fluent, instance, false);
  }
  public VaultAppRoleBuilder(VaultAppRoleFluent<?> fluent,VaultAppRole instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new VaultAppRole());

    if (instance != null) {
      fluent.withPath(instance.getPath());
      fluent.withRoleId(instance.getRoleId());
      fluent.withSecretRef(instance.getSecretRef());
      fluent.withPath(instance.getPath());
      fluent.withRoleId(instance.getRoleId());
      fluent.withSecretRef(instance.getSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VaultAppRoleBuilder(VaultAppRole instance) {
    this(instance,false);
  }
  public VaultAppRoleBuilder(VaultAppRole instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new VaultAppRole());

    if (instance != null) {
      this.withPath(instance.getPath());
      this.withRoleId(instance.getRoleId());
      this.withSecretRef(instance.getSecretRef());
      this.withPath(instance.getPath());
      this.withRoleId(instance.getRoleId());
      this.withSecretRef(instance.getSecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  VaultAppRoleFluent<?> fluent;
  Boolean validationEnabled;
  public VaultAppRole build() {
    VaultAppRole buildable = new VaultAppRole(fluent.getPath(),fluent.getRoleId(),fluent.buildSecretRef());
    return buildable;
  }
  
}
